/* 
 * The Finite State Machine Explorer
 * Copyright (c) 1995-1996
 * Matt Chapman (csuoq@csv.warwick.ac.uk)
 * Dept. Computer Science
 * University of Warwick, Coventry, UK.
 */

package Machine;

/**
 * A simple class to represent two floating point co-ordinates.
 * @version    21 Nov 1995
 * @author     Matt Chapman
 */
public final class Coord 
{
    /** the X co-ordinate */
    public float x;

    /** the Y co-ordinate */
    public float y;
    
    /**
     * Create a new co-ordinate initialized to the origin.
     */
    public Coord() 
    {
		  this.x = 0.0f;
		  this.y = 0.0f;
    }

    /**
     * Create a new co-ordinate with the given values.
     * @param x   the X co-ordinate to be stored
     * @param y   the Y co-ordinate to be stored
     */
    public Coord(float x, float y) 
    {
		  this.x = x;
		  this.y = y;
    }
    /**
     * Create a new co-ordinate from the given one
     * @param c the co-ordinate to be duplicated
     */
    public Coord(Coord c) 
    {
		  this.x = c.x;
		  this.y = c.y;
    }

    /**
     * Returns the distance between the current and the given co-ordinate pair.
     * @param x   the X co-ordinate of the point of interest
     * @param y   the Y co-ordinate of the point of interest
     * @return    the distance between the two points
     */
    public float dist(float x, float y) 
    {
		  return((float)Math.sqrt((x - this.x) * (x - this.x) + 
										  (y - this.y) * (y - this.y)));
    }

    /**
     * Returns the distance between the current and the given co-ordinate.
     * @param d   the co-ordinate of the point of interest
     * @return    the distance between the two co-ordinates
     */
    public float dist(Coord d) 
    {
		  return((float)Math.sqrt((d.x - this.x) * (d.x - this.x) +
										  (d.y - this.y) * (d.y - this.y)));
    }
}
