/* 
 * The Finite State Machine Explorer
 * Copyright (c) 1995-1996
 * Matt Chapman (csuoq@csv.warwick.ac.uk)
 * Dept. Computer Science
 * University of Warwick, Coventry, UK.
 */

package Machine;

import java.awt.*;

/**
 * A class to provide some simple online documentation
 * @version 13 March 1996
 * @author  Matt Chapman
 */
public final class Help extends Dialog
{
    // the instruction text
    private String txt = "\n Instructions \n ------------ \n  \n Construction: \n  \n Click in the main window to create new states, when in \n add mode. \n  \n To connect states, select connect mode, then click on \n the state the connection is to originate from, so that \n it changes colour to green. Then click on the \n destination state, which should also become green. Then \n press a key for that transition, to create the \n connection.  Valid characters for transitions are upper \n and lower case letters, and digits. Pressing any other \n key will cancel the connection operation. \n  \n A valid machine must have a start state which can be \n designated when in start mode. \n  \n Toggle mode changes the acceptance status of \n states. All states are initially non-accepting. \n  \n The current mode can be changed by selecting from the \n toolbar, or by pressing the first letter of the mode \n name. \n  \n States can be repositioned by dragging them with the \n mouse when in move mode. \n  \n Delete mode can be used to remove states or \n connections. Click on the transition character(s) to \n remove a connection. \n  \n  \n General: \n  \n The green panner widget can be used to scroll around \n the virtual workspace in which the machine may be \n contructed. \n  \n The zoom slider can be used to vary the current scaling \n of the on-screen representation of the machine, from \n 50% to 200% of the default scaling. \n  \n The \"Start New\" button will delete the entire machine. \n  \n  \n Simulation: \n  \n To simulate a machine, enter an input string, select \n the required simulation speed, and click on the \n simulation button. The input string is processed one \n character at a time, and the currently active state (or \n states, if the machine is non-deterministic) will \n change colour to green. \n  \n  \n Advanced Operations: \n  \n The \"Deterministic?\" button will determine whether the \n current machine is deterministic - that is there is \n never more than one transition for a particular \n character originating from a state. \n  \n The \"Auto Layout\" button will discard the machine's \n positional information and attempt to layout the states \n in such a way as to optimise the layout according to \n some criteria. However the method in full has \n complexity O(n!), where n is the number of states. So, \n only a couple of entries are chosen, at random. Thus \n the generated layout will generally be \n suboptimal. Clicking on the button again will repeat \n the process, which will probably give a different \n layout. \n  \n The \"Remove Inacc\" button will remove any inaccessible \n states from the current machine. \n  \n The \"Minimize\" button will remove inaccessible states, \n complete the machine (add any missing transitions to a \n non-accepting state), find any indistinguishable \n states, and merge them together, to form a minimal \n machine. This is only applicable to deterministic \n machines. \n  \n The \"NonDet -> Det\" button will convert the current \n non-deterministic machine to a deterministic \n machine. The states of the deterministic machine are \n the elements of the power set of the states of the \n non-deterministic machine. This routine has complexity \n O(2^n), where n is the number of states, so will be \n very slow for large machines. \n  \n The above two operations call the layout routine to \n position the generated machines. \n  \n  \n Input / Output: \n  \n When running as an application, the following \n capabilities are available, from the \"File\" menu. \n  \n \"Save machine\" and \"Save machine as\" write a full \n description of the current machine to a file. \n  \n \"Load machine\" reads a previously saved machine \n description, and reconstructs the machine, wiping any \n current machine. \n  \n \"Output PostScript\" pops up a dialog box which can be \n used to output a description of the machine in the \n PostScript language. The page output can be portrait or \n landscape in orientation, and can have a title. \n\n";

    public Help(Frame f)
    {
		  super(f, "Help",false); 

		  // create the popup
		  Panel p = new Panel();
		  TextArea htext = new TextArea(txt,20,59);
		  htext.setEditable(false);
		  htext.setFont(new Font("Courier", Font.PLAIN, 12));
		  p.add("Center",htext);
		  add("Center",p);
		  add("South",new Button(" Dismiss "));
		  resize(450, 370);
	 }

    public boolean action(Event event, Object arg)
    {
		  if (event.target instanceof Button)
		  {
				// user has clicked on dismiss button so close the box
				hide();
				repaint();
		  }
		  return true;
    }
}
