/* 
 * The Finite State Machine Explorer
 * Copyright (c) 1995-1996
 * Matt Chapman (csuoq@csv.warwick.ac.uk)
 * Dept. Computer Science
 * University of Warwick, Coventry, UK.
 */

package Machine;

import java.awt.*;
import java.util.*;
import java.applet.Applet;
import java.lang.*;
import java.io.*;
import java.net.*;

/**
 * Central applet and main function for the Finite State Machine Explorer
 * @version    24 Nov 1996
 * @author     Matt Chapman
 */

/* the main controls at the bottom of the applet */
final class ControlPanel extends Panel 
{

    MainWidget mainw;
    // constants
    final int wid=570, hei=342;
    final int twid=1140, thei=600;

    Panel create() 
    {
		  Panel p = new Panel();

		  // create the interface
		  p.setLayout(new FlowLayout(FlowLayout.CENTER,0,0));
		  p.setFont(new Font("Helvetica", Font.PLAIN, 10));
	
		  WPanner pw = new WPanner(60,36,wid,hei,wid/2,hei/2,mainw);
		  pw.setValue(0,0);
		  mainw.pannerw = pw;
		  p.add(pw);
		  p.add(new Label("Zoom:",Label.RIGHT));
		  ZoomSlide sl = new ZoomSlide(mainw);
		  mainw.zoomw = sl;
		  sl.SetWidth(150);
		  sl.SetValue(100);
		  sl.SetMinimum(50);
		  sl.SetMaximum(200);
		  p.add(sl);

		  Panel q = new Panel();
		  p.add(q);
		  Button sb = new Button("Simulate");
		  q.add(sb);	
		  mainw.simbutton = sb;
		  TextField tf = new TextField(10);
		  mainw.inputfield = tf;
		  q.add(tf);
		  Choice sp = new Choice();
        sp.addItem("Slow");
		  sp.addItem("Medium");
		  sp.addItem("Fast");
		  sp.addItem("Very fast");
		  sp.addItem("Jump to end");
		  mainw.simspeed = sp;
		  sp.select(1);
		  q.add(sp);

		  Panel r = new Panel();
		  p.add(r);

		  r.add(new Button("Start New"));
		  r.add(new Button("Deterministic?"));
		  r.add(new Button("Auto Layout"));
		  r.add(new Button("Remove inacc"));
		  r.add(new Button("Minimize"));
		  r.add(new Button("NonDet -> Det"));

		  return p;
    }

    ControlPanel(MainWidget mw) 
    {
		  mainw=mw;
		  setLayout(new CardLayout());
		  add("South",create());
		  //add(create(new FlowLayout(FlowLayout.CENTER,0,0)));
    }
    
    public Dimension preferredSize() 
    {
		  return new Dimension(590, 200);
    }
}

// the central class - calls all the others
public final class Main extends Applet 
{
    MainWidget mainwidget;
    static mFrame f = null;

    // this is only called if run as an application, not an applet
    public static void main(String args[])
    {
		  f = new mFrame("The Finite State Machine Explorer");	
        Main main = new Main();
        main.init();
        f.add("Center",main);
		  f.resize(600,515);
        f.show();
    }

    /* create main display */
    public void init() 
    {
		  setBackground(Color.lightGray);
		  Panel centerPanel = new Panel();
		  Font titlefont = new Font("Helvetica", Font.BOLD, 18);
		  Font msgfont = new Font("Helvetica", Font.BOLD, 12);

		  setLayout(new BorderLayout(0,0));
		  add("Center", centerPanel);
		  mainwidget = new MainWidget();
		  centerPanel.add(mainwidget);
		  Label msg = new Label("                   Welcome to the Finite State Machine Explorer                   ",Label.CENTER);
		  msg.setFont(msgfont);
		  centerPanel.add(msg);
		  mainwidget.setMsg(msg);
		  if (f != null) // run as an application
				f.setMain(mainwidget);
		  Panel controlPanel = new ControlPanel(mainwidget);
		  centerPanel.add(controlPanel);

		  // load button image
		  Image bt;
		  if (f != null) // run as an application - use local file access
		  {
				bt = Toolkit.getDefaultToolkit().getImage("buttons.gif");
		  }
		  else // run as an applet - use URL
		  {
				URL url;
				try
				{
					 url = new URL(getDocumentBase(),"buttons.gif");
				} catch (MalformedURLException e)
				{
					 return;
				}
				bt = Toolkit.getDefaultToolkit().getImage(url);
		  }    

		  MediaTracker tracker = new MediaTracker(this);
		  tracker.addImage(bt,0);
		  //wait for picture to load
		  try 
		  {
				tracker.waitForID(0);
		  } catch (InterruptedException e) 
		  {
				return;
		  }
		  mainwidget.buttons = bt;
		  if (bt.getWidth(this) < 0)
		  {
				System.out.println("Error: Couldn't load button image");
		  }
    }

    // handle events
    public boolean action(Event e, Object obj)
    {
		  if ("Simulate".equals(obj)) 
		  {
				mainwidget.simulate();
				return true;
		  }
		  else if ("Stop".equals(obj))
		  {
				mainwidget.stopsim();
				return true;
		  }
		  else if ("Start New".equals(obj))
		  {
				mainwidget.startNew();
				return true;
		  }
		  else if ("Deterministic?".equals(obj))
		  {
				mainwidget.isDet();
				return true;
		  }
		  else if ("Auto Layout".equals(obj))
		  {
				mainwidget.doLayout();
				return true;
		  }
		  else if ("Minimize".equals(obj))
		  {
				mainwidget.minimize();
				return true;
		  }
		  else if ("Remove inacc".equals(obj))
		  {
				mainwidget.remInacc();
				return true;
		  }
		  else if ("NonDet -> Det".equals(obj)) 
		  {
				mainwidget.nfa();
				return true;
		  }
	
		  return false;
    }
}
