/* 
 * The Finite State Machine Explorer
 * Copyright (c) 1995-1996
 * Matt Chapman (csuoq@csv.warwick.ac.uk)
 * Dept. Computer Science
 * University of Warwick, Coventry, UK.
 */

package Machine;

import java.awt.*;

/**
 * A preferences dialog box for PostScript output
 * @version    7 March 1996
 * @author     Matt Chapman
 */
public final class PSDialog extends Dialog
{
    // AWT components for dialog
    private Button browse,okay,cancel;
    private TextField tfield,nfield;
    private Choice orient;
    private mFrame mf;
    private MainWidget mainw;

    // add a label component to the dialog
    private void makelabel(String name, GridBagLayout gridbag,
									GridBagConstraints c)
    {
        Label label = new Label(name,Label.RIGHT);
        gridbag.setConstraints(label, c);
        add(label);
    }

    PSDialog(mFrame mfr, MainWidget mw) {
		  super(mfr, "PostScript options", true);
		  mf = mfr;
		  mainw = mw;

		  // create the dialog
		  GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints c = new GridBagConstraints();
		  setLayout(gridbag);
		  c.fill = GridBagConstraints.HORIZONTAL;
        c.weightx = 0.0;
		  c.weighty = 1.0;

		  c.gridwidth = GridBagConstraints.REMAINDER;
		  Label label = new Label("Output machine as PostScript",Label.CENTER);
		  label.setFont(new Font("Helvetica", Font.BOLD, 12));
		  gridbag.setConstraints(label, c);
        add(label);
		  setFont(new Font("Helvetica", Font.PLAIN, 12));

		  c.gridwidth = 1;
        makelabel("Orientation:", gridbag, c);
		  c.gridwidth = GridBagConstraints.REMAINDER;
		  orient = new Choice();
		  orient.addItem("Portrait");
		  orient.addItem("Landscape");
		  gridbag.setConstraints(orient,c);
		  add(orient);

		  c.weightx = 0.0;
		  c.gridwidth = 1;
        makelabel("Optional Title:", gridbag, c);
		  c.gridwidth = GridBagConstraints.REMAINDER;
		  tfield = new TextField(25);
		  gridbag.setConstraints(tfield,c);
		  add(tfield);

		  c.weightx = 0.0;
		  c.gridwidth = 1;
        makelabel("Filename:", gridbag, c);

		  nfield = new TextField(15);
		  gridbag.setConstraints(nfield,c);
		  add(nfield);

		  c.gridwidth = GridBagConstraints.REMAINDER;
        browse = new Button("Browse...");
        gridbag.setConstraints(browse, c);
        add(browse);
	
		  Panel panel = new Panel();
		  okay = new Button("   OK   ");	
		  gridbag.setConstraints(okay,c);
		  panel.add(okay);
		  c.gridwidth = GridBagConstraints.REMAINDER;
		  cancel = new Button(" Cancel ");
		  gridbag.setConstraints(cancel,c);
		  panel.add(cancel);
		  c.gridwidth = 1;
		  c.gridx = 1;
		  gridbag.setConstraints(panel,c);
		  add(panel);
		  resize(335, 205);
    }
    
    public boolean action(Event event, Object arg) {
		  if (event.target == okay)
		  {
				// generate the PostScript
				mainw.genPS(nfield.getText(),tfield.getText(),
								"Portrait".equals(orient.getSelectedItem()));
				hide();
				repaint();
		  }
		  else if (event.target == cancel)
		  {
				// dismiss box
				hide();
				repaint();
		  }
		  else if (event.target == browse)
		  {
				// select a filename
				FileDialog df = new FileDialog(mf,
														 "Select file to save Postscript output in:",FileDialog.SAVE);
				df.show();
				if ((df.getFile() != null) && (df.getFile().length()>0))
				{
					 nfield.setText(df.getDirectory()+df.getFile());
				}
				repaint();
		  }
		  return true;
    }
}
