/* 
 * The Finite State Machine Explorer
 * Copyright (c) 1995-1996
 * Matt Chapman (csuoq@csv.warwick.ac.uk)
 * Dept. Computer Science
 * University of Warwick, Coventry, UK.
 */

package Machine;

/**
 * A class to represent a single state in a finite state machine
 * @version    24 Jan 1996
 * @author     Matt Chapman
 */
public final class State 
{

    // the coordinate of the centre of the state
    private Coord position;

    // the acceptance status of the state
    private boolean accepting = false;

    // the state's ID
    private int id;

    // for numbering states
    static private int cid=0;

    // constant for state size
    public final float radius = 0.01f;

    /**
     * Creates a new state.
     */
    public State() 
    {
		  position = new Coord();
		  id=cid++;
    }

    /**
     * Sets the position of the state in physical co-ordinates.
     * @param p the co-ordinate of the state
     */
    public void setPos(Coord p) 
    {
		  position = p;
    }

    /**
     * Returns the physical co-ordinate of the centre of the state.
     * @return the physical co-ordinate
     */
    public Coord getPos() 
    {
		  return position;
    }

    /**
     * Makes the state accepting. If the state is already accepting, this will
     * have no effect. The default is for the state to be rejecting.
     */
    public void makeAccepting() 
    {
		  accepting = true;
    }

    /**
     * Makes the state rejecting. If the state is already rejecting, this will
     * have no effect. All states are by default rejecting.
     */
    public void makeRejecting() 
    {
		  accepting = false;
    }

    /** 
     * Returns the acceptance status of the state
     * @return true for accepting, false otherwise
     */
    public boolean isAccepting() 
    {
		  return accepting;
    }

    /**
     * @return the ID of the state
     */
    public int getID()
    {
		  return id;
    }

    /**
     * Return state information as a String.
     * @return the String representation of the state details
     */
    public String toString() 
    {
		  String s = new String("state"+id+" ");
		  return s;
    }
}
