/* 
 * The Finite State Machine Explorer
 * Copyright (c) 1995-1996
 * Matt Chapman (csuoq@csv.warwick.ac.uk)
 * Dept. Computer Science
 * University of Warwick, Coventry, UK.
 */

package Machine;

import java.awt.*;
import java.io.*;

// for handling events from the menu bar
public final class mFrame extends Frame 
{
    private MainWidget mainwidget;
    private String fullname = null;
    private static String currname = null;

    mFrame(String title)
    {
		  super(title);
		  appMenu m = new appMenu();		
		  setMenuBar(m.getMenuBar());
    }

    public void saveAs()
    {
		  FileDialog df = new FileDialog(this,"Select file to save machine in:",FileDialog.SAVE);
		  df.show();
		  String fname = df.getFile();
		  if ((fname != null) && (fname.length()>0))
		  {
				repaint();
				fullname = df.getDirectory()+fname;
				File f = new File(fullname);
				if (f.isFile())
				{
					 mDialog d = new mDialog(this,
													 "Overwrite file "+fname+"?",this);
					 d.show();
				}
				else
				{
					 doSave(true);
				}
		  }
		  repaint();
		  mainwidget.repaint();
    }

    public void doSave(boolean okay)
    {
		  repaint();
		  if (okay)
		  {
				mainwidget.saveMC(fullname);
				if (currname != fullname)
				{
					 currname = new String(fullname);
				}
		  }
		  repaint();
    }

    public boolean handleEvent(Event e)
    {
		  if (e.target instanceof MenuItem)
		  {
				String s = (String)e.arg;
				if ("Save machine".equals(s))
				{
					 if (currname == null)
					 {
						  saveAs();
					 }
					 else
					 {
						  fullname = currname;
						  doSave(true);
					 }
					 repaint();
					 return true;
				}
				else if ("Save machine as...".equals(s))
				{
					 saveAs();
					 return true;
				}
				else if ("Load machine...".equals(s))
				{
					 FileDialog df = new FileDialog(this,"Select file to load machine from:",FileDialog.LOAD);
					 //FSMFilter filt = new FSMFilter();
					 //df.setFilenameFilter(filt);
					 df.show();
					 mainwidget.pannerw.repaint();
					 mainwidget.zoomw.repaint();
					 mainwidget.repaint();
					 if ((df.getFile() != null) && (df.getFile().length()>0))
						  mainwidget.loadMC(df.getDirectory()+df.getFile());
					 repaint();
					 return true;
				}
				else if ("Output PostScript...".equals(s))
				{
					 PSDialog d = new PSDialog(this,mainwidget);
					 d.show();
					 repaint();
					 return true;
				}
				else if ("Quit".equals(s))
				{
					 System.exit(0);
				}
				else if ("About".equals(s))
				{
					 About adialog = new About(this);
					 adialog.show();
				}
				else if ("Instructions".equals(s))
				{
					 Help hdialog = new Help(this);
					 hdialog.show();
				}
		  }
		  return false;
    }

    public void setMain(MainWidget mw)
    {
		  mainwidget = mw;
    }
}


// a confirm dialog for saving to a file
final class mDialog extends Dialog
{
    private Button okay,cancel;
    private mFrame mf;

    mDialog(Frame dw, String title, mFrame mfr) {
		  super(dw, "Confirm popup", true);
		  mf = mfr;

		  Panel p = new Panel();
		  Label label = new Label(title);
		  p.add("Center",label);
		  add("Center",p);
		  Panel panel = new Panel();
		  panel.resize(220,5);
		  okay = new Button("   OK   ");
        cancel = new Button("  Cancel  ");
        panel.add("West",okay);
        panel.add("East",cancel);
		  add("South",panel);
		  resize(310, 100);
    }
    
    public boolean action(Event event, Object arg) {
		  if ((event.target == okay) || (event.target == cancel))
		  {
				hide();
				mf.doSave((Button)event.target == okay);
		  }
		  return true;
	 }
}
